013ccd312d93bfb526241f9d81c4327a3b169b2e
kate
  Tue Aug 9 14:52:59 2016 -0700
Extend gtexAse file format to include quartiles, donors. Add GTEx abbreviation to tissue table.  Generalize the new hub as GTex analysis.

diff --git src/hg/lib/gtexAse.sql src/hg/lib/gtexAse.sql
index 3e57170..952d44e 100644
--- src/hg/lib/gtexAse.sql
+++ src/hg/lib/gtexAse.sql
@@ -1,22 +1,28 @@
 # gtexAse.sql was originally generated by the autoSql program, which also 
 # generated gtexAse.c and gtexAse.h.  This creates the database representation of
 # an object which can be loaded and saved from RAM in a fairly 
 # automatic way.
 
 #BED9+ with additional fields for ASE, coverage, and sample count
 CREATE TABLE gtexAse (
     chrom varchar(255) not null,	# Reference sequence chromosome or scaffold
     chromStart int unsigned not null,	# Start position in chromosome
     chromEnd int unsigned not null,	# End position in chromosome
     name varchar(255) not null,	# SNP Id
     score int unsigned not null,	# Score from 0-1000; derived from median ASE level
     strand char(1) not null,	# n/a
     thickStart int unsigned not null,	# n/a
     thickEnd int unsigned not null,	# n/a
-    rgb int unsigned not null,	# Color by ASE value
-    ASE float not null,	# Allelic imbalance (0-.5)
+    itemRgb int unsigned not null,	# Color by ASE value
+    medianASE float not null,	# Allelic imbalance (0-.5) median
     coverage float not null,	# RNA-seq reads overlapping this position
     samples int unsigned not null,	# Sample count
+    donors int unsigned not null,	# Donor count
+    minASE float not null,	# Minimum ASE
+    q1ASE float not null,	# Q1 ASE
+    q3ASE float not null,	# Q3 ASE
+    maxASE float not null,	# Maximum ASE
+    stdASE float not null,	# ASE standard deviation
               #Indices
     INDEX(chrom(20), chromStart)
 );